export const interacting: string
export const inner: string
export const header: string
export const content: string
export const collapsed: string
export const minimized: string
export const footer: string
export const grip: string
export const title: string
export const controls: string
export const ctrl: string
export const pin: string
export const pinned: string
export const collapse: string
export const minimize: string
export const maximize: string
export const maximized: string
export const close: string
export const handle: string
export const resize_top: string
export const resize_bottom: string
export const resize_left: string
export const resize_right: string
export const resize_top_left: string
export const resize_top_right: string
export const resize_bottom_left: string
export const resize_bottom_right: string
export default ""
