export declare function defer(): Promise<void>;
export declare function delay(ms: number): Promise<void>;
export declare function poll(fn: () => boolean, interval?: number, timeout?: number): Promise<void>;
export declare function paint(): Promise<void>;
export declare function idle(): Promise<void>;
//# sourceMappingURL=defer.d.ts.map